@@ -9,6 +9,10 @@ from napoleontoolbox.signal import signal_utility
 import json
 import hashlib
 
+import pickle
+
+from pathlib import Path
+
 def unjsonize_mapping_dataframe(mapping_df):
     human_readable_dictionary = {}
     json_params_dictionary = {}
@@ -220,3 +224,13 @@ class ParallelRunResultAnalyzer():
         print('downloaoding from dropbox the results to '+self.db_path)
         self.dbx.local_sqlite_overwrite_from_db(sqlite_file_name=self.filename,local_root_directory = self.local_root_directory)
 
+    def save_pickled_list_to_dropbox(self, list_to_save=None, local_root_directory= None, list_pkl_file_name = None):
+        full_path = local_root_directory + list_pkl_file_name
+        with open(full_path, 'wb') as f:
+            pickle.dump(list_to_save, f)
+        print('uploading to dropbox')
+        self.dbx.upload(fullname=full_path, folder='', subfolder='', name=list_pkl_file_name,overwrite=True)
+
+    def read_pickled_list_from_dropbox(self, list_pkl_file_name = None):
+        raw_data = self.dbx.download_pkl(pkl_file_name=list_pkl_file_name)
+        return raw_data
